yakumo.keystone.v3.region

Package yakumo :: Package keystone :: Package v3 :: Module region |
[hide private]
[frames] | no frames]

# Source Code for Module yakumo.keystone.v3.region

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Resource class and its manager for regions in Identity V3 API
    18  """
    19
    20  from yakumo import base
    21  from yakumo.constant import UNDEF
    22  from yakumo import mapper
    23
    24
    25  ATTRIBUTE_MAPPING = [
    26      ('id', 'id', mapper.Noop),
    27      ('description', 'description', mapper.Noop),
    28      ('parent', 'parent_region_id', mapper.Resource('keystone.region')),
    29  ]
    30
    31
    32 -class Resource(base.Resource):
    33      """resource class for regions on Identity V3 API"""
    34
    35 -    def update(self, description=UNDEF, parent=UNDEF):
    36          """
    37          Update properties of a region
    38
    39          @keyword description: Description
    40          @type description: str
    41          @keyword parent: Parent region
    42          @type parent: yakumo.keystone.v3.region.Resource
    43          @rtype: None
    44          """
    45          super(Resource, self).update(
    46              description=description,
    47              parent=parent)
    48
    49
    50 -class Manager(base.Manager):
    51      """manager class for regions on Identity V3 API"""
    52
    53      resource_class = Resource
    54      service_type = 'identity'
    55      _attr_mapping = ATTRIBUTE_MAPPING
    56      _json_resource_key = 'region'
    57      _json_resources_key = 'regions'
    58      _update_method = 'patch'
    59      _url_resource_path = '/regions'
    60
    61 -    def create(self, id=UNDEF, description=UNDEF, parent=UNDEF):
    62          """
    63          Register a region
    64
    65          @keyword id: ID
    66          @type id: str
    67          @keyword description: Description
    68          @type description: str
    69          @keyword parent: Parent region
    70          @type parent: yakumo.keystone.v3.region.Resource
    71          @return: Created region
    72          @rtype: yakumo.keystone.v3.region.Resource
    73          """
    74          return super(Manager, self).create(
    75              id=id,
    76              description=description,
    77              parent=parent)
    78